==> prestashop_edition_basic_version_8.0.4.zip: modules/ps_accounts/translations/es.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
global $_MODULE;
$_MODULE = [];
$_MODULE['<{ps_accounts}prestashop>ps_accounts_40047b296fb8a4952e0512c7184e1ca3'] = 'PrestaShop Account';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_9006e8a0d8ca7f627146d32bc9c0eb73'] = 'Vincula tu tienda a tu cuenta PrestaShop para activar y gestionar tus suscripciones en tu back office. No desinstales este módulo si tienes una suscripción vigente.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_ceeadaf870d9eaa81cf1fbe32614af64'] = 'Esta acción impedirá inmediatamente que tus servicios PrestaShop y los servicios de la Comunidad funcionen, ya que utilizan el módulo PrestaShop Account para la autenticación.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_01a84505e1f42ba1b80ffed4f9f21221'] = 'Esta tienda está vinculada a tu cuenta PrestaShop. Desvincula tu tienda si no quieres que afecte a tu configuración live.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_d82864f800210969f401370615e30568'] = 'Algunas tiendas están vinculadas a tu cuenta PrestaShop. La eliminación de estas tiendas afectará a tu configuración live.';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuración';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Centro de ayuda';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_b7ca62f12bc3b8e0d6422c028473a265'] = 'Tu cuenta PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_518d650937979216a269cf9830a7b484'] = 'Una cuenta para gestionar todas tus tiendas PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_655aa4af96bbb20cf78e14b560affb38'] = 'Crea tu cuenta PrestaShop o inicia sesión en tu cuenta existente';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_d23c41d498fe8587fb2f6ac563426dce'] = 'Vincula tu tienda a tu cuenta';
$_MODULE['<{ps_accounts}prestashop>content_23feb5280da1e3a86dc0fcc048f1a58d'] = 'Un back-office fácil de usar';
$_MODULE['<{ps_accounts}prestashop>content_e661ffe463ad9b9bcea4c49d744058e7'] = 'Gestiona todo tu negocio en un solo lugar: catálogo de productos, pedidos, pagos, envíos y mucho más.';
$_MODULE['<{ps_accounts}prestashop>content_8ea4efcd82809db344ff0d7a76695448'] = 'Todo lo esencial para tu negocio';
$_MODULE['<{ps_accounts}prestashop>content_f27ec0e8d78513e2e60830c62a3a13b8'] = 'Marketing, pagos y análisis de rendimiento: la suite PrestaShop Essentials incluye todas las funciones que necesitas para que tu tienda tenga éxito.';
$_MODULE['<{ps_accounts}prestashop>content_f2d32f40a4060af2595051d0ab0278cb'] = 'Una solución 100% personalizable';
$_MODULE['<{ps_accounts}prestashop>content_9b4e2d0b927094565d6ce673644868a4'] = 'PrestaShop acompaña tu crecimiento. Encuentra nuestros módulos y los de nuestros partners en PrestaShop Marketplace para personalizar y desarrollar tu tienda';
$_MODULE['<{ps_accounts}prestashop>content_1ab1f34b16d32fa54b90ee0f91f39dfd'] = 'Bienvenido,';
$_MODULE['<{ps_accounts}prestashop>content_474684646f833216fdaf79c606af208b'] = 'Accede a tu back office para gestionar tu tienda.';
$_MODULE['<{ps_accounts}prestashop>content_6ed6a381a1de805e2b807f88a95faa2b'] = 'Ir al back office';
$_MODULE['<{ps_accounts}prestashop>content_8905a5daaa6744846452108776efa036'] = 'Conectar con otro método  ';
$_MODULE['<{ps_accounts}prestashop>content_729f27762821b8ec88f1a656be7dff72'] = 'Primero tienes que activar tu cuenta haciendo clic en el enlace del correo electrónico. Si necesitas recibir un nuevo enlace de activación, [1]haz clic aquí[/1]';
$_MODULE['<{ps_accounts}prestashop>content_476ff05d1175f9a35d268828caf300f2'] = 'Se ha producido un error durante el inicio de sesión, ponte en contacto con el soporte de PrestaShop';
$_MODULE['<{ps_accounts}prestashop>content_fd359ea79740b865e45c2bf6fe5d3ab1'] = 'No puedes acceder al back office con esta cuenta. Intenta otra cuenta o contacta con tu administrador.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_e53a9fbe0e31ac65b72e5e2c876074d8'] = 'Gestione tu cuenta PrestaShop';

==> prestashop_edition_basic_version_8.2.0.zip: modules/ps_accounts/translations/es.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
global $_MODULE;
$_MODULE = [];
$_MODULE['<{ps_accounts}prestashop>ps_accounts_40047b296fb8a4952e0512c7184e1ca3'] = 'PrestaShop Account';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_248ed4a0f71472c36d19bb0f1bcb68a0'] = 'Vincule su tienda a su cuenta PrestaShop para activar y gestionar sus suscripciones en su back office. No desinstale este módulo si tiene una suscripción en vigor.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_ceeadaf870d9eaa81cf1fbe32614af64'] = 'Esta acción impedirá inmediatamente que tus servicios PrestaShop y los servicios de la Comunidad funcionen, ya que utilizan el módulo PrestaShop Account para la autenticación.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_01a84505e1f42ba1b80ffed4f9f21221'] = 'Esta tienda está vinculada a tu cuenta PrestaShop. Desvincula tu tienda si no quieres que afecte a tu configuración live.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_d82864f800210969f401370615e30568'] = 'Algunas tiendas están vinculadas a tu cuenta PrestaShop. La eliminación de estas tiendas afectará a tu configuración live.';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_f4f70727dc34561dfde1a3c529b6205c'] = 'Configuración';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Centro de ayuda';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_b7ca62f12bc3b8e0d6422c028473a265'] = 'Tu cuenta PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_53c4c7fe12fffd658daacfa5b41eb495'] = 'Una cuenta para gestionar todas sus tiendas PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_655aa4af96bbb20cf78e14b560affb38'] = 'Crea tu cuenta PrestaShop o inicia sesión en tu cuenta existente';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_a60d78ec73c0c133ce16b10419a3fdf6'] = 'Vincule su tienda a su cuenta';
$_MODULE['<{ps_accounts}prestashop>content_23feb5280da1e3a86dc0fcc048f1a58d'] = 'Un back-office fácil de usar';
$_MODULE['<{ps_accounts}prestashop>content_e661ffe463ad9b9bcea4c49d744058e7'] = 'Gestiona todo tu negocio en un solo lugar: catálogo de productos, pedidos, pagos, envíos y mucho más.';
$_MODULE['<{ps_accounts}prestashop>content_8ea4efcd82809db344ff0d7a76695448'] = 'Todo lo esencial para tu negocio';
$_MODULE['<{ps_accounts}prestashop>content_f27ec0e8d78513e2e60830c62a3a13b8'] = 'Marketing, pagos y análisis de rendimiento: la suite PrestaShop Essentials incluye todas las funciones que necesitas para que tu tienda tenga éxito.';
$_MODULE['<{ps_accounts}prestashop>content_f2d32f40a4060af2595051d0ab0278cb'] = 'Una solución 100% personalizable';
$_MODULE['<{ps_accounts}prestashop>content_9b4e2d0b927094565d6ce673644868a4'] = 'PrestaShop acompaña tu crecimiento. Encuentra nuestros módulos y los de nuestros partners en PrestaShop Marketplace para personalizar y desarrollar tu tienda';
$_MODULE['<{ps_accounts}prestashop>content_1ab1f34b16d32fa54b90ee0f91f39dfd'] = 'Bienvenido,';
$_MODULE['<{ps_accounts}prestashop>content_474684646f833216fdaf79c606af208b'] = 'Accede a tu back office para gestionar tu tienda.';
$_MODULE['<{ps_accounts}prestashop>content_6ed6a381a1de805e2b807f88a95faa2b'] = 'Ir al back office';
$_MODULE['<{ps_accounts}prestashop>content_8905a5daaa6744846452108776efa036'] = 'Conectar con otro método  ';
$_MODULE['<{ps_accounts}prestashop>content_729f27762821b8ec88f1a656be7dff72'] = 'Primero tienes que activar tu cuenta haciendo clic en el enlace del correo electrónico. Si necesitas recibir un nuevo enlace de activación, [1]haz clic aquí[/1]';
$_MODULE['<{ps_accounts}prestashop>content_476ff05d1175f9a35d268828caf300f2'] = 'Se ha producido un error durante el inicio de sesión, ponte en contacto con el soporte de PrestaShop';
$_MODULE['<{ps_accounts}prestashop>content_fd359ea79740b865e45c2bf6fe5d3ab1'] = 'No puedes acceder al back office con esta cuenta. Intenta otra cuenta o contacta con tu administrador.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_e53a9fbe0e31ac65b72e5e2c876074d8'] = 'Gestione tu cuenta PrestaShop';
